==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AbsoluteVolumeOscillatorIndicatorDescription } from "./AbsoluteVolumeOscillatorIndicatorDescription";
/**
 * @hidden
 */
var AbsoluteVolumeOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata, _super);
    function AbsoluteVolumeOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a == null) {
            AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.c(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.g(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
    };
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
    };
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.d = function (a) {
        AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.b(a);
        a.u("AbsoluteVolumeOscillatorIndicator", function () { return new AbsoluteVolumeOscillatorIndicatorDescription(); });
        a.t("AbsoluteVolumeOscillatorIndicator", AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
    };
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.$t = markType(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata, 'AbsoluteVolumeOscillatorIndicatorDescriptionMetadata');
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a = null;
    return AbsoluteVolumeOscillatorIndicatorDescriptionMetadata;
}(Base));
export { AbsoluteVolumeOscillatorIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { AbsoluteVolumeOscillatorIndicatorDescription } from "./AbsoluteVolumeOscillatorIndicatorDescription";
/**
 * @hidden
 */
var AbsoluteVolumeOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata, _super);
    function AbsoluteVolumeOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a == null) {
            AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.c(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.j(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
    };
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
    };
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.d = function (a) {
        AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.b(a);
        a.aa("AbsoluteVolumeOscillatorIndicator", function () { return new AbsoluteVolumeOscillatorIndicatorDescription(); });
        a.z("AbsoluteVolumeOscillatorIndicator", AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a);
    };
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.$t = markType(AbsoluteVolumeOscillatorIndicatorDescriptionMetadata, 'AbsoluteVolumeOscillatorIndicatorDescriptionMetadata');
    AbsoluteVolumeOscillatorIndicatorDescriptionMetadata.a = null;
    return AbsoluteVolumeOscillatorIndicatorDescriptionMetadata;
}(Base));
export { AbsoluteVolumeOscillatorIndicatorDescriptionMetadata };
